@@ -26,7 +26,12 @@ from google.iam.v1 import policy_pb2
 from google.type import expr_pb2
 
 
-_shared_modules = [iam_policy_pb2, options_pb2, policy_pb2, expr_pb2]
+_shared_modules = [
+    iam_policy_pb2,
+    options_pb2,
+    policy_pb2,
+    expr_pb2,
+]
 
 _local_modules = []
 
